float out = 0.0;

try
{
  double x = 461739.812;
  double y = 4506731.316;
  double buffer = 10.0;
  wchar_t wsFeatureClassName[64];
  wsFeatureClassName = "default";

  /* create a buffer */
  FdoDouble dMinX = x - buffer;
  FdoDouble dMaxX = x + buffer;
  FdoDouble dMinY = y - buffer;
  FdoDouble dMaxY = y + buffer;
  FdoPtr<FdoIEnvelope> envelope =
    m_geometryFactory->CreateEnvelopeXY(dMinX, dMinY, dMaxX, dMaxY);
  FdoPtr<FdoIGeometry> geometryFilter =
    m_geometryFactory->CreateGeometry(envelope);
  FdoPtr<FdoByteArray> byteArray =
    m_geometryFactory->GetFgf(geometryFilter);
  FdoPtr<FdoGeometryValue> geoValue = FdoGeometryValue::Create(byteArray);

  /* create select command */
  FdoPtr<FdoISelect> cmdSelect =
      (FdoISelect *)m_connection->CreateCommand(FdoCommandType_Select);
  cmdSelect->SetFeatureClassName(wsFeatureClassName);
  FdoPtr<FdoFilter> filter = FdoSpatialCondition::Create(L"Raster",
    FdoSpatialOperations_Intersects, geoValue);
  cmdSelect->SetFilter(filter);

  /* create clip function */
  FdoPtr<FdoExpressionCollection> funcParams =
    FdoExpressionCollection::Create();
  FdoPtr<FdoIdentifier> rasterProp = FdoIdentifier::Create(L"Raster");
  funcParams->Add(rasterProp);
  FdoPtr<FdoDataValue> minX =
    FdoDataValue::Create(dMinX, FdoDataType_Double);
  funcParams->Add(minX);
  FdoPtr<FdoDataValue> minY =
    FdoDataValue::Create(dMinY, FdoDataType_Double);
  funcParams->Add(minY);
  FdoPtr<FdoDataValue> maxX =
    FdoDataValue::Create((FdoInt32(dMaxX)));
  funcParams->Add(maxX);
  FdoPtr<FdoDataValue> maxY =
    FdoDataValue::Create(dMaxY, FdoDataType_Double);
  funcParams->Add(maxY);
  FdoPtr<FdoFunction> clipFunc = FdoFunction::Create(L"CLIP", funcParams);
  FdoPtr<FdoComputedIdentifier> clipIdentifier =
    FdoComputedIdentifier::Create(L"clippedRaster", clipFunc );

  /* set clip function */
  FdoPtr<FdoIdentifierCollection> propsToSelect =
    cmdSelect->GetPropertyNames();
  propsToSelect->Add(clipIdentifier);

  /* execute command */
  FdoPtr<FdoIFeatureReader> featureReader = cmdSelect->Execute();

  /* read result */
  if (featureReader->ReadNext())
  {
    /* get raster */
    /*************************************************************************/
    /************************ this call causes memory leak *******************/
    /*************************************************************************/
    FdoPtr<FdoIRaster> raster = featureReader->GetRaster(L"clippedRaster");
    
    /* get data model */
    FdoPtr<FdoRasterDataModel> dataModel = raster->GetDataModel();

    /* check */
    FdoInt32 bpp = dataModel->GetBitsPerPixel();
    if (bpp != 32)
      return DNG_FAILURE;

    /* scale */
    raster->SetImageXSize(3);
    raster->SetImageYSize(3);
    dataModel->SetTileSizeX(raster->GetImageXSize());
    dataModel->SetTileSizeY(raster->GetImageYSize());
    raster->SetDataModel(dataModel);

    /* read value */
    FdoPtr<FdoIStreamReaderTmpl<FdoByte> > reader =
      static_cast<FdoIStreamReaderTmpl<FdoByte>*>(
      raster->GetStreamReader());
    FdoInt32 length = (FdoInt32)reader->GetLength();
    FdoByte *data = new FdoByte[(size_t)length];
    reader->ReadNext(data, 0, length);

    /* to float */
    memcpy(&out, &(data[4 * sizeof(out)]), sizeof(out));

    delete [] data;
  }

  featureReader->Close();
}
catch( FdoException * ge)
{
  ge->Release();
}
